# WyFy 

A small utility script to print WiFi SSID/passwords on Windows using  `netsh`


## Installation
```bash
$ pip install wyfy
```

## Usage
```bash
$ wyfy [*| SSID substring]
```

Running it without arguments shows the currently connected network(s) SSID and password